#!/opt/concourse/worker/volumes/live/4bfdf998-c189-4d1a-5cfd-f212c6a9172f/volume/anaconda-navigator_1632168924589/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/Anaconda-Navigator.app/Contents/MacOS/python
from subprocess import call

call(["/opt/concourse/worker/volumes/live/4bfdf998-c189-4d1a-5cfd-f212c6a9172f/volume/anaconda-navigator_1632168924589/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/bin/anaconda-navigator"])
